# -*- coding: utf-8 -*-
#
# File: conference.py
#
# Copyright (c) 2007 by []
# Generator: ArchGenXML Version 1.5.0
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#

__author__ = """Josef Milota <milota@jcu.cz>"""
__docformat__ = 'plaintext'


from Products.CMFCore.utils import getToolByName
from Products.CMFCore.WorkflowTool import addWorkflowFactory
from Products.DCWorkflow.DCWorkflow import DCWorkflowDefinition
from Products.ExternalMethod.ExternalMethod import ExternalMethod
from Products.conference.config import *

##code-section create-workflow-module-header #fill in your manual code here
##/code-section create-workflow-module-header


productname = 'conference'

def setupconference_review_workflow(self, workflow):
    """Define the conference_review_workflow workflow.
    """
    # Add additional roles to portal
    portal = getToolByName(self,'portal_url').getPortalObject()
    data = list(portal.__ac_roles__)
    for role in ['Author']:
        if not role in data:
            data.append(role)
    portal.__ac_roles__ = tuple(data)

    workflow.setProperties(title='conference_review_workflow')

    ##code-section create-workflow-setup-method-header #fill in your manual code here
    ##/code-section create-workflow-setup-method-header


    for s in ['reviewed', 'rejected', 'private', 'visible']:
        workflow.states.addState(s)

    for t in ['retract', 'hide', 'reject', 'show', 'reviewed']:
        workflow.transitions.addTransition(t)

    for v in ['review_history', 'comments', 'time', 'actor', 'action']:
        workflow.variables.addVariable(v)

    workflow.addManagedPermission('View')
    workflow.addManagedPermission('Modify portal content')
    workflow.addManagedPermission('Access contents information')
    workflow.addManagedPermission('conference: View review comment')

    for l in []:
        if not l in workflow.worklists.objectValues():
            workflow.worklists.addWorklist(l)

    ## Initial State

    workflow.states.setInitialState('private')

    ## States initialization

    stateDef = workflow.states['reviewed']
    stateDef.setProperties(title="""reviewed""",
                           transitions=['retract', 'reject', 'hide'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner', 'Reviewer', 'Author'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner', 'Reviewer'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner', 'Reviewer', 'Author'])
    stateDef.setPermission('conference: View review comment',
                           0,
                           ['Manager', 'Owner', 'Reviewer'])

    stateDef = workflow.states['rejected']
    stateDef.setProperties(title="""rejected""",
                           transitions=['retract', 'reviewed', 'hide'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner', 'Reviewer', 'Author'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner', 'Reviewer'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner', 'Reviewer', 'Author'])
    stateDef.setPermission('conference: View review comment',
                           0,
                           ['Manager', 'Owner', 'Reviewer'])

    stateDef = workflow.states['private']
    stateDef.setProperties(title="""private""",
                           transitions=['show'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner'])
    stateDef.setPermission('conference: View review comment',
                           0,
                           ['Manager', 'Owner'])

    stateDef = workflow.states['visible']
    stateDef.setProperties(title="""visible""",
                           transitions=['reviewed', 'reject', 'hide'])
    stateDef.setPermission('View',
                           0,
                           ['Manager', 'Owner', 'Reviewer', 'Author'])
    stateDef.setPermission('Modify portal content',
                           0,
                           ['Manager', 'Owner', 'Reviewer'])
    stateDef.setPermission('Access contents information',
                           0,
                           ['Manager', 'Owner', 'Reviewer', 'Author'])
    stateDef.setPermission('conference: View review comment',
                           0,
                           ['Manager', 'Owner', 'Reviewer'])

    ## Transitions initialization

    ## Creation of workflow scripts
    for wf_scriptname in ['setArticlePrivate']:
        if not wf_scriptname in workflow.scripts.objectIds():
            workflow.scripts._setObject(wf_scriptname,
                ExternalMethod(wf_scriptname, wf_scriptname,
                productname + '.conference_review_workflow_scripts',
                wf_scriptname))

    transitionDef = workflow.transitions['retract']
    transitionDef.setProperties(title="""retract""",
                                new_state_id="""visible""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""setArticlePrivate""",
                                actbox_name="""retract""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;Owner;Reviewer'},
                                )

    ## Creation of workflow scripts
    for wf_scriptname in ['setPrivateState']:
        if not wf_scriptname in workflow.scripts.objectIds():
            workflow.scripts._setObject(wf_scriptname,
                ExternalMethod(wf_scriptname, wf_scriptname,
                productname + '.conference_review_workflow_scripts',
                wf_scriptname))

    transitionDef = workflow.transitions['hide']
    transitionDef.setProperties(title="""hide""",
                                new_state_id="""private""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""setPrivateState""",
                                actbox_name="""hide""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Modify portal content', 'guard_roles': 'Manager;Owner'},
                                )

    ## Creation of workflow scripts
    for wf_scriptname in ['setArticleRejected']:
        if not wf_scriptname in workflow.scripts.objectIds():
            workflow.scripts._setObject(wf_scriptname,
                ExternalMethod(wf_scriptname, wf_scriptname,
                productname + '.conference_review_workflow_scripts',
                wf_scriptname))

    transitionDef = workflow.transitions['reject']
    transitionDef.setProperties(title="""reject""",
                                new_state_id="""rejected""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""setArticleRejected""",
                                actbox_name="""reject""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;Owner;Reviewer'},
                                )

    ## Creation of workflow scripts
    for wf_scriptname in ['setReviewRoles']:
        if not wf_scriptname in workflow.scripts.objectIds():
            workflow.scripts._setObject(wf_scriptname,
                ExternalMethod(wf_scriptname, wf_scriptname,
                productname + '.conference_review_workflow_scripts',
                wf_scriptname))

    transitionDef = workflow.transitions['show']
    transitionDef.setProperties(title="""show""",
                                new_state_id="""visible""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""setReviewRoles""",
                                actbox_name="""show""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_permissions': 'Modify portal content', 'guard_roles': 'Manager;Owner'},
                                )

    ## Creation of workflow scripts
    for wf_scriptname in ['setArticleReviewed']:
        if not wf_scriptname in workflow.scripts.objectIds():
            workflow.scripts._setObject(wf_scriptname,
                ExternalMethod(wf_scriptname, wf_scriptname,
                productname + '.conference_review_workflow_scripts',
                wf_scriptname))

    transitionDef = workflow.transitions['reviewed']
    transitionDef.setProperties(title="""reviewed""",
                                new_state_id="""reviewed""",
                                trigger_type=1,
                                script_name="""""",
                                after_script_name="""setArticleReviewed""",
                                actbox_name="""reviewed""",
                                actbox_url="""""",
                                actbox_category="""workflow""",
                                props={'guard_roles': 'Manager;Owner;Reviewer'},
                                )

    ## State Variable
    workflow.variables.setStateVar('review_state')

    ## Variables initialization
    variableDef = workflow.variables['review_history']
    variableDef.setProperties(description="""Provides access to workflow history""",
                              default_value="""""",
                              default_expr="""state_change/getHistory""",
                              for_catalog=0,
                              for_status=0,
                              update_always=0,
                              props={'guard_permissions': 'Request review; Review portal content'})

    variableDef = workflow.variables['comments']
    variableDef.setProperties(description="""Comments about the last transition""",
                              default_value="""""",
                              default_expr="""python:state_change.kwargs.get('comment', '')""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['time']
    variableDef.setProperties(description="""Time of the last transition""",
                              default_value="""""",
                              default_expr="""state_change/getDateTime""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['actor']
    variableDef.setProperties(description="""The ID of the user who performed the last transition""",
                              default_value="""""",
                              default_expr="""user/getId""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    variableDef = workflow.variables['action']
    variableDef.setProperties(description="""The last transition""",
                              default_value="""""",
                              default_expr="""transition/getId|nothing""",
                              for_catalog=0,
                              for_status=1,
                              update_always=1,
                              props=None)

    ## Worklists Initialization


    # WARNING: below protected section is deprecated.
    # Add a tagged value 'worklist' with the worklist name to your state(s) instead.

    ##code-section create-workflow-setup-method-footer #fill in your manual code here
    ##/code-section create-workflow-setup-method-footer



def createconference_review_workflow(self, id):
    """Create the workflow for conference.
    """

    ob = DCWorkflowDefinition(id)
    setupconference_review_workflow(self, ob)
    return ob

addWorkflowFactory(createconference_review_workflow,
                   id='conference_review_workflow',
                   title='conference_review_workflow')

##code-section create-workflow-module-footer #fill in your manual code here
##/code-section create-workflow-module-footer

